<?php
add_action('init', 'my_custom_init_gallery');
function my_custom_init_gallery() 
{
  $labels = array(
    'name' => _x('Gallery', 'post type general name', 'ocmx'),
    'singular_name' => _x('Gallery', 'post type singular name', 'ocmx'),
    'add_new' => _x('Add Gallery Item', 'Gallery', 'ocmx'),
    'add_new_item' => __('Add New Gallery Item', 'ocmx'),
    'edit_item' => __('Edit ', 'ocmx'),
    'new_item' => __('New Gallery Item', 'ocmx'),
    'view_item' => __('View Gallery Item', 'ocmx'),
    'search_items' => __('Search Gallery Items', 'ocmx'),
    'not_found' =>  __('No Gallery items found', 'ocmx'),
    'not_found_in_trash' => __('No Gallery items found in Trash', 'ocmx'), 
    'parent_item_colon' => ''
  );
  $args = array(
    'labels' => $labels,
    'public' => true,
    'publicly_queryable' => true,
    'show_ui' => true, 
    'query_var' => true,
    'rewrite' => true,
    'menu_icon' => get_stylesheet_directory_uri() . '/ocmx/images/portfolio-icon.png',
    'capability_type' => 'post',
    'hierarchical' => false,
    'menu_position' => null,
    'supports' => array('title','editor','author','thumbnail','excerpt','comments', 'page-attributes')
  ); 
  register_post_type('Gallery',$args);
	
	/****************************************************************/
	/* Gallery Post Type Custom Meta, here used to add a category */
	
	register_taxonomy( 'gallery-category', 'gallery', array( 'hierarchical' => true, 'label' => 'Categories', 'query_var' => true, 'rewrite' => true ) );  
}

//add filter to insure the text Gallery, or Gallery, is displayed when user updates a Gallery 
add_filter('post_updated_messages', 'gallery_updated_messages');
function gallery_updated_messages( $messages ) {
  global $post, $post_ID;

  $messages['Gallery'] = array(
    0 => '', // Unused. Messages start at index 1.
    1 => sprintf( __('Gallery Item updated. <a href="%s">View Gallery item</a>'), esc_url( get_permalink($post_ID) ) ),
    2 => __('Custom field updated.', 'ocmx'),
    3 => __('Custom field deleted.', 'ocmx'),
    4 => __('Product updated.', 'ocmx'),
    /* translators: %s: date and time of the revision */
    5 => isset($_GET['revision']) ? sprintf( __('Gallery restored to revision from %s', 'ocmx'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
    6 => sprintf( __('Gallery Item published. <a href="%s">View Gallery item</a>'), esc_url( get_permalink($post_ID) ) ),
    7 => __('Product saved.', 'ocmx'),
    8 => sprintf( __('Gallery Item submitted. <a target="_blank" href="%s">Preview Gallery item</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
    9 => sprintf( __('Gallery Item scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Gallery item</a>'),
      // translators: Publish box date format, see http://php.net/date
      date_i18n( __( 'M j, Y @ G:i', 'ocmx' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
    10 => sprintf( __('Gallery Item draft updated. <a target="_blank" href="%s">Preview Gallery item</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
  );

  return $messages;
}

add_filter( 'manage_edit-gallery_columns', 'ocmx_edit_gallery_columns' ) ;

function ocmx_edit_gallery_columns( $columns ) {

	$columns = array(
		'cb' => '<input type="checkbox" />',
		'title' => __( 'Title', 'ocmx' ),
		'Gallery-category' => __( 'Category', 'ocmx' ),
		'date' => __( 'Date', 'ocmx' )
	);

	return $columns;
}

add_action( 'manage_gallery_posts_custom_column', 'ocmx_manage_gallery_columns', 10, 2 );

function ocmx_manage_gallery_columns( $column, $post_id ) {
	global $post, $post_id;

	switch( $column ) {


		/* If displaying the 'genre' column. */
		case 'gallery-category' :

			/* Get the genres for the post. */
			$terms = get_the_terms( $post_id, 'gallery-category' );

			/* If terms were found. */
			if ( !empty( $terms ) ) {

				$out = array();

				/* Loop through each term, linking to the 'edit posts' page for the specific term. */
				foreach ( $terms as $term ) {
					$out[] = sprintf( '<a href="%s">%s</a>',
						esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'gallery-category' => $term->slug ), 'edit.php' ) ),
						esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'gallery-category', 'display' ) )
					);
				}

				/* Join the terms, separating them with a comma. */
				echo join( ', ', $out );
			}

			/* If no terms were found, output a default message. */
			else {
				echo __( 'No Categories', 'ocmx' );
			}

			break;

		/* Just break out of the switch statement for everything else. */
		default :
			break;
	}
}

?>